@@ -17,12 +17,9 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_ftp_client_restart_marker.c
- *
- * $RCSfile: globus_ftp_client_restart_marker.c,v $
- * $Revision: 1.10 $
- * $Date: 2011/02/03 21:47:03 $
+ * @brief Globus GridFTP client restart marker
  */
-#endif
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
 
 #include "globus_i_ftp_client.h"
 #include <string.h>
@@ -450,7 +447,6 @@ globus_ftp_client_restart_marker_set_offset(
  *
  * @return
  *        - Error on NULL marker or total bytes
- *        - <possible return>
  */
 globus_result_t
 globus_ftp_client_restart_marker_get_total(
