@@ -15,14 +15,11 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
- * @file globus_ftp_client_restart_plugin.c GridFTP Restart Plugin Implementation
- *
- * $RCSfile: globus_ftp_client_restart_plugin.c,v $
- * $Revision: 1.27.10.1 $
- * $Date: 2011/12/14 01:24:40 $
+ * @file globus_ftp_client_restart_plugin.c
+ * @brief GridFTP Restart Plugin Implementation
  */
-#endif
 
 #include "globus_i_ftp_client.h"
 #include "globus_ftp_client_restart_plugin.h"
@@ -31,7 +28,6 @@
 #include <string.h>
 #include "version.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 #define GLOBUS_L_FTP_CLIENT_RESTART_PLUGIN_NAME "globus_ftp_client_restart_plugin"
 
 #define GLOBUS_L_FTP_CLIENT_RESTART_PLUGIN_RETURN(plugin) \
@@ -1223,7 +1219,7 @@ void globus_l_ftp_client_restart_plugin_response(
             return;
         }
 
-        /* parse out bytes transfered */
+        /* parse out bytes transferred */
         tmp_ptr = strstr(buffer, "Stripe Bytes Transferred:");
         if(tmp_ptr == NULL)
         {
@@ -1622,7 +1618,7 @@ globus_ftp_client_restart_plugin_init(
     GLOBUS_FTP_CLIENT_RESTART_PLUGIN_SET_FUNC(plugin,
         response);
 
-    env_str = globus_libc_getenv("GUC_STALL_TIMEOUT");
+    env_str = getenv("GUC_STALL_TIMEOUT");
     if(env_str != NULL)
     {
         int                             sc;
